@@ -9,13 +9,14 @@ import urllib2
 from flask import current_app
 from flask.ext.script import Manager
 
+from extends import preprocess
+
 manager = Manager(usage="Asset bundling")
 
+
 @manager.command
 def bundle_assets():
     """Compress and minify assets"""
-
-    LESS_BIN = current_app.config.get('LESS_BIN', 'lessc')
     YUI_COMPRESSOR_BIN = current_app.config.get('YUI_COMPRESSOR_BIN')
 
     path_to_jar = YUI_COMPRESSOR_BIN
@@ -103,13 +104,9 @@ def bundle_assets():
                 print ' - Not a valid remote file %s' % filename
                 return None
 
-        if filename.endswith('.less'):
-            fp = get_path(filename.lstrip('/'))
-            subprocess.call('%s %s %s.css' % (LESS_BIN, fp, fp),
-                            shell=True, stdout=subprocess.PIPE)
-            filename = '%s.css' % filename
+        filename = preprocess(filename.lstrip('/'))
 
-        if url is None:
+        if url is None and filename.endswith('.css'):
             filename = fix_urls(filename, compressed_file)
             tmp_files.append(filename)
 
@@ -117,28 +114,30 @@ def bundle_assets():
 
     def minify(ftype, file_in, file_out):
         """Minify the file"""
-        if ftype == 'js' and current_app.config.has_key('UGLIFY_BIN'):
+        if ftype == 'js' and 'UGLIFY_BIN' in current_app.config:
             o = {'method': 'UglifyJS',
                  'bin': current_app.config.get('UGLIFY_BIN')}
             subprocess.call("%s -o %s %s" % (o['bin'], file_out, file_in),
                             shell=True, stdout=subprocess.PIPE)
-        elif ftype == 'css' and current_app.config.has_key('CLEANCSS_BIN'):
+        elif ftype == 'css' and 'CLEANCSS_BIN' in current_app.config:
             o = {'method': 'clean-css',
                  'bin': current_app.config.get('CLEANCSS_BIN')}
             subprocess.call("%s -o %s %s" % (o['bin'], file_out, file_in),
-                       shell=True, stdout=subprocess.PIPE)
+                            shell=True, stdout=subprocess.PIPE)
         else:
             o = {'method': 'YUI Compressor',
                  'bin': current_app.config.get('JAVA_BIN')}
             variables = (o['bin'], path_to_jar, file_in, file_out)
             subprocess.call("%s -jar %s %s -o %s" % variables,
-                       shell=True, stdout=subprocess.PIPE)
+                            shell=True, stdout=subprocess.PIPE)
 
         print "Minifying %s (using %s)" % (file_in, o['method'])
 
     # Assemble bundles and process
-    bundles = {'css': current_app.config.get('CSS_BUNDLES'),
-               'js': current_app.config.get('JS_BUNDLES'),}
+    bundles = {
+        'css': current_app.config.get('CSS_BUNDLES'),
+        'js': current_app.config.get('JS_BUNDLES'),
+    }
 
     for ftype, bundle in bundles.iteritems():
         for name, files in bundle.iteritems():
@@ -155,6 +154,7 @@ def bundle_assets():
             all_files = []
             for fn in files:
                 processed = preprocess_file(fn, compressed_file)
+                print 'Processed: %s' % processed
                 if processed is not None:
                     all_files.append(processed)
 
@@ -162,8 +162,10 @@ def bundle_assets():
             if len(all_files) == 0:
                 print "Warning: '%s' is an empty bundle." % bundle
 
-            subprocess.call("cat %s > %s" %
-                (' '.join(all_files), concatenated_file), shell=True)
+            all_files = ' '.join(all_files)
+
+            subprocess.call("cat %s > %s" % (all_files, concatenated_file),
+                            shell=True)
 
             # Minify
             minify(ftype, concatenated_file, compressed_file)
@@ -185,4 +187,4 @@ def bundle_assets():
         os.rmdir(get_path(os.path.join(current_app.config.get('BUNDLES_DIR'),
                                        'tmp')))
     except OSError:
-        pass
\ No newline at end of file
+        pass
